/* 
 *  Author: Chris Lord <chris@openedhand.com>
 *
 *  Copyright (c) 2007 OpenedHand Ltd - http://www.openedhand.com/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */

#ifndef JANA_ECAL_UTILS_H
#define JANA_ECAL_UTILS_H

#include <time.h>
#include <glib.h>
#include <libjana/jana-time.h>

/**
 * JANA_ECAL_LOCATION_KEY:
 *
 * The GConf key path used to store the ecal timezone location. This will be 
 * checked by jana_ecal_utils_guess_location() before any other method. For 
 * convenience, this path is the same path Evolution uses to store its 
 * ecal timezone location.
 */
#define JANA_ECAL_LOCATION_KEY "/apps/evolution/calendar/display/timezone"

/**
 * JANA_ECAL_LOCATION_KEY_DIR:
 * @see_also: #JANA_ECAL_LOCATION_KEY
 *
 * The parent directory of the GConf key used to store the ecal timezone
 * location. If #JANA_ECAL_LOCATION_KEY exists, this GConf directory can be 
 * monitored to detect when it has changed. See also #JANA_ECAL_LOCATION_KEY.
 */
#define JANA_ECAL_LOCATION_KEY_DIR "/apps/evolution/calendar/display"

JanaTime * jana_ecal_utils_time_now (const gchar *location);
JanaTime * jana_ecal_utils_time_today (const gchar *location);
gchar * jana_ecal_utils_guess_location ();
gchar ** jana_ecal_utils_get_locations ();

#endif

